DIRAC WebApp
============

.. image:: https://badge.fury.io/py/WebAppDIRAC.svg
    :target: https://badge.fury.io/py/WebAppDIRAC

Web app extension for the `DIRAC project <https://github.com/DIRACGrid/DIRAC>`_. WebAppDIRAC is written using extjs 6.2.0 and python 3.

Status master branch (stable):

.. image:: https://github.com/DIRACGrid/WebAppDIRAC/workflows/Basic%20tests/badge.svg?branch=rel-v4r3
   :target: https://github.com/DIRACGrid/WebAppDIRAC/actions?query=workflow%3A%22Basic+tests%22+branch%3Arel-v4r3
   :alt: Basic Tests Status

Status integration branch (devel):

.. image:: https://github.com/DIRACGrid/WebAppDIRAC/workflows/Basic%20tests/badge.svg?branch=integration
   :target: https://github.com/DIRACGrid/WebAppDIRAC/actions?query=workflow%3A%22Basic+tests%22+branch%3Aintegration
   :alt: Basic Tests Status



Install
-------

Instructions for installing WebAppDIRAC are described `here <https://github.com/DIRACGrid/DIRAC/blob/integration/docs/source/AdministratorGuide/ServerInstallations/InstallingWebAppDIRAC.rst#installing-webappdirac>`_.
